summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchat.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /libkdegames/kchat.h
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/kchat.h')
-rw-r--r--libkdegames/kchat.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkdegames/kchat.h b/libkdegames/kchat.h
index a28578c7..f6867c68 100644
--- a/libkdegames/kchat.h
+++ b/libkdegames/kchat.h
@@ -39,12 +39,12 @@ class KDE_EXPORT KChat : public KChatBase
TQ_OBJECT
public:
/**
* @param tqparent The tqparent widget for this widget.
* @param twoPlayerGame If true the combo box where the player can
* choose to send to a single player or to all players will not be added
* as you will hardly need it in 2-player games.
**/
- KChat(TQWidget* tqparent, bool twoPlayerGame = false);
+ KChat(TQWidget* parent, bool twoPlayerGame = false);
virtual ~KChat();
@@ -39,12 +39,12 @@ class KDE_EXPORT KChat : public KChatBase
public:
/**
- * @param tqparent The tqparent widget for this widget.
+ * @param parent The parent widget for this widget.
* @param twoPlayerGame If true the combo box where the player can
* choose to send to a single player or to all players will not be added